# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
import urllib.request

from trytond.pool import Pool
from trytond.tests.test_tryton import ModuleTestCase, with_transaction


class ProductImageAttributeTestCase(ModuleTestCase):
    'Test Product Image Attribute module'
    module = 'product_image_attribute'

    @with_transaction()
    def test_image_attribute(self):
        "Test image with attribute"
        pool = Pool()
        Attribute = pool.get('product.attribute')
        AttributeSet = pool.get('product.attribute.set')
        Image = pool.get('product.image')
        Product = pool.get('product.product')
        Template = pool.get('product.template')
        Uom = pool.get('product.uom')

        attribute1 = Attribute(name='attr1', string="Attribute 1")
        attribute1.type_ = 'char'
        attribute1.save()
        attribute2 = Attribute(name='attr2', string="Attribute 2")
        attribute2.type_ = 'integer'
        attribute2.save()
        attribute_set = AttributeSet(name="Attribute Set")
        attribute_set.attributes = [attribute1, attribute2]
        attribute_set.save()
        template = Template(name="Template")
        template.default_uom, = Uom.search([], limit=1)
        template.attribute_set = attribute_set
        product = Product(template=template)
        product.attributes = {
            'attr1': 'foo',
            'attr2': 2,
            }
        product.save()
        image1 = Image(template=template)
        image1.image = urllib.request.urlopen(
            'https://picsum.photos/200').read()
        image1.save()
        image2 = Image(template=template, product=product)
        image2.image = urllib.request.urlopen(
            'https://picsum.photos/200').read()
        image2.save()
        image3 = Image(template=template)
        image3.image = urllib.request.urlopen(
            'https://picsum.photos/200').read()
        image3.attributes = {
            'attr1': 'foo',
            }
        image3.save()
        image4 = Image(template=template)
        image4.image = urllib.request.urlopen(
            'https://picsum.photos/200').read()
        image4.attributes = {
            'attr1': 'bar',
            }
        image4.save()

        self.assertEqual(list(product.images_used), [image2, image1, image3])


del ModuleTestCase



#!/usr/bin/env python3
# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

import io
import os
import re
from configparser import ConfigParser

from setuptools import find_packages, setup


def read(fname):
    content = io.open(
        os.path.join(os.path.dirname(__file__), fname),
        'r', encoding='utf-8').read()
    content = re.sub(
        r'(?m)^\.\. toctree::\r?\n((^$|^\s.*$)\r?\n)*', '', content)
    return content


def get_require_version(name):
    if minor_version % 2:
        require = '%s >= %s.%s.dev0, < %s.%s'
    else:
        require = '%s >= %s.%s, < %s.%s'
    require %= (name, major_version, minor_version,
        major_version, minor_version + 1)
    return require


config = ConfigParser()
config.read_file(open(os.path.join(os.path.dirname(__file__), 'tryton.cfg')))
info = dict(config.items('tryton'))
for key in ('depends', 'extras_depend', 'xml'):
    if key in info:
        info[key] = info[key].strip().splitlines()
version = info.get('version', '0.0.1')
major_version, minor_version, _ = version.split('.', 2)
major_version = int(major_version)
minor_version = int(minor_version)
name = 'trytond_product_image_attribute'

download_url = 'http://downloads.tryton.org/%s.%s/' % (
    major_version, minor_version)
if minor_version % 2:
    version = '%s.%s.dev0' % (major_version, minor_version)
    download_url = (
        'hg+http://hg.tryton.org/modules/%s#egg=%s-%s' % (
            name[8:], name, version))

local_version = []
if os.environ.get('CI_JOB_ID'):
    local_version.append(os.environ['CI_JOB_ID'])
else:
    for build in ['CI_BUILD_NUMBER', 'CI_JOB_NUMBER']:
        if os.environ.get(build):
            local_version.append(os.environ[build])
        else:
            local_version = []
            break
if local_version:
    version += '+' + '.'.join(local_version)
requires = []
for dep in info.get('depends', []):
    if not re.match(r'(ir|res)(\W|$)', dep):
        requires.append(get_require_version('trytond_%s' % dep))
requires.append(get_require_version('trytond'))

tests_require = []
dependency_links = []
if minor_version % 2:
    dependency_links.append(
        'https://trydevpi.tryton.org/?local_version='
        + '.'.join(local_version)
        )

setup(name=name,
    version=version,
    description='Tryton module to select variant images based on attributes',
    long_description=read('README.rst'),
    author='Tryton',
    author_email='bugs@tryton.org',
    url='http://www.tryton.org/',
    download_url=download_url,
    project_urls={
        "Bug Tracker": 'https://bugs.tryton.org/',
        "Documentation": (
            'https://docs.tryton.org/projects/'
            'modules-product-image-attribute'),
        "Forum": 'https://www.tryton.org/forum',
        "Source Code": 'https://hg.tryton.org/modules/product_image_attribute',
        },
    keywords='tryton product image attribute',
    package_dir={'trytond.modules.product_image_attribute': '.'},
    packages=(
        ['trytond.modules.product_image_attribute']
        + ['trytond.modules.product_image_attribute.%s' % p
            for p in find_packages()]
        ),
    package_data={
        'trytond.modules.product_image_attribute': (info.get('xml', [])
            + ['tryton.cfg', 'view/*.xml', 'locale/*.po', '*.fodt',
                'icons/*.svg', 'tests/*.rst']),
        },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Plugins',
        'Framework :: Tryton',
        'Intended Audience :: Developers',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Legal Industry',
        'License :: OSI Approved :: '
        'GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: Bulgarian',
        'Natural Language :: Catalan',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Czech',
        'Natural Language :: Dutch',
        'Natural Language :: English',
        'Natural Language :: Finnish',
        'Natural Language :: French',
        'Natural Language :: German',
        'Natural Language :: Hungarian',
        'Natural Language :: Indonesian',
        'Natural Language :: Italian',
        'Natural Language :: Persian',
        'Natural Language :: Polish',
        'Natural Language :: Portuguese (Brazilian)',
        'Natural Language :: Romanian',
        'Natural Language :: Russian',
        'Natural Language :: Slovenian',
        'Natural Language :: Spanish',
        'Natural Language :: Turkish',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Office/Business',
        ],
    license='GPL-3',
    python_requires='>=3.7',
    install_requires=requires,
    extras_require={
        'test': tests_require,
        },
    dependency_links=dependency_links,
    zip_safe=False,
    entry_points="""
    [trytond.modules]
    product_image_attribute = trytond.modules.product_image_attribute
    """,  # noqa: E501
    )
